@@ -30,20 +30,22 @@ my $prebuilt_binaries = [
       cc_re    => qr/gcc/,
     },
     {
-      title    => "Binaries Win/32bit SDL-1.2.14 (20090831)\n" .
-                  "\t(gfx, image, mixer, net, smpeg, ttf)",
+      title    => "Binaries Win/32bit SDL-1.2.14 (extended, 20111205)\n" .
+                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
       url      => [
-        'http://strawberryperl.com/package/kmx/sdl/lib-SDL-bin_win32_v2.zip',
-        'http://froggs.de/libsdl/lib-SDL-bin_win32_v2.zip',
+        'http://strawberryperl.com/package/kmx/sdl/Win32_SDL-1.2.14-extended-bin_20111205.zip',	
+        'http://froggs.de/libsdl/Win32_SDL-1.2.14-extended-bin_20111205.zip',
       ],
-      sha1sum  => 'eaeeb96b0115462f6736de568de8ec233a2397a5',
+      sha1sum  => '553b7e21bb650d047ec9f2a5f650c67d76430e61',
       arch_re  => qr/^MSWin32-x86-multi-thread$/,
       os_re    => qr/^MSWin32$/,
       cc_re    => qr/gcc/,
     },
     {
-      title    => "Binaries Win/64bit SDL-1.2.14 (extended, 20100824) RECOMMENDED\n" .
-                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
+      title    => "Binaries Win/64bit SDL-1.2.14 (extended, 20100824)\n" .
+                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)\n" .
+                  "\tBEWARE: binaries are using old ABI - will fail with the latest gcc\n" .
+                  "\tBEWARE: this is intended just for old strawberryperl 5.12.x/64bit",
       url      => [
         'http://strawberryperl.com/package/kmx/sdl/Win64_SDL-1.2.14-extended-bin_20100824.zip',	
         'http://froggs.de/libsdl/Win64_SDL-1.2.14-extended-bin_20100824.zip',
@@ -52,6 +54,20 @@ my $prebuilt_binaries = [
       arch_re  => qr/^MSWin32-x64-multi-thread$/,
       os_re    => qr/^MSWin32$/,
       cc_re    => qr/gcc/,
+      gccversion_re => qr/^4\.4\.3$/, #specific to the old gcc compiler used in 64bit strawberryperl 5.12.x
+    },
+    {
+      title    => "Binaries Win/64bit SDL-1.2.14 (extended, 20111205) RECOMMENDED\n" .
+                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
+      url      => [
+        'http://strawberryperl.com/package/kmx/sdl/Win64_SDL-1.2.14-extended-bin_20111205.zip',	
+        'http://froggs.de/libsdl/Win64_SDL-1.2.14-extended-bin_20111205.zip',
+      ],
+      sha1sum  => '35f3b496ca443a9d14eff77e9e26acfa813afafd',
+      arch_re  => qr/^MSWin32-x64-multi-thread$/,
+      os_re    => qr/^MSWin32$/,
+      cc_re    => qr/gcc/,
+      gccversion_re => qr/^4\.(4\.[5-9]|[5-9]\.[0-9])$/,
     },
  ];
 
@@ -91,6 +107,8 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
+          'SDL-1.2.14-video_mmx.patch',
         ],
       },
       {
@@ -119,7 +137,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
+          #'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -132,7 +150,10 @@ my $source_packs = [
           'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
         ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
-        patches => [ ],
+        patches => [
+          'SDL_image-1.2.10-libpng-flags.patch',
+          'SDL_image-1.2.10-libpng15.patch',
+        ],
       },
       {
         pack => 'SDL_mixer',
@@ -205,6 +226,8 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
+          'SDL-1.2.14-video_mmx.patch',
         ],
       },
       {
@@ -215,7 +238,10 @@ my $source_packs = [
           'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
         ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
-        patches => [ ],
+        patches => [
+          'SDL_image-1.2.10-libpng-flags.patch',
+          'SDL_image-1.2.10-libpng15.patch',
+        ],
       },
       {
         pack => 'SDL_mixer',
@@ -287,6 +313,8 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
+          'SDL-1.2.14-video_mmx.patch',
         ],
       },
       {
@@ -327,7 +355,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
+          #'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -340,7 +368,10 @@ my $source_packs = [
           'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
         ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
-        patches => [ ],
+        patches => [
+          'SDL_image-1.2.10-libpng-flags.patch',
+          'SDL_image-1.2.10-libpng15.patch',
+        ],
       },
       {
         pack => 'SDL_mixer',
@@ -394,6 +425,8 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
+          'SDL-1.2.14-video_mmx.patch',
         ],
       },
       {
@@ -434,7 +467,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
+          #'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -447,7 +480,10 @@ my $source_packs = [
           'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
         ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
-        patches => [ ],
+        patches => [
+          'SDL_image-1.2.10-libpng-flags.patch',
+          'SDL_image-1.2.10-libpng15.patch',
+        ],
       },
       {
         pack => 'SDL_mixer',
@@ -519,7 +555,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
+          #'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -543,6 +579,8 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
+          'SDL-1.2.14-video_mmx.patch',
         ],
       },
       {
@@ -553,7 +591,10 @@ my $source_packs = [
           'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
         ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
-        patches => [ ],
+        patches => [
+          'SDL_image-1.2.10-libpng-flags.patch',
+          'SDL_image-1.2.10-libpng15.patch',
+        ],
       },
       {
         pack => 'SDL_mixer',
@@ -618,7 +659,9 @@ sub check_prebuilt_binaries
   foreach my $b (@{$prebuilt_binaries}) {
     if ( ($^O =~ $b->{os_re}) &&
          ($Config{archname} =~ $b->{arch_re}) &&
-         ($cc =~ $b->{cc_re}) ) {
+         ($cc =~ $b->{cc_re}) &&
+         (!defined $b->{gccversion_re} || $Config{gccversion} =~ $b->{gccversion_re})
+        ) {      
       $b->{buildtype} = 'use_prebuilt_binaries';
       push @good, $b;
     }
@@ -651,6 +694,7 @@ sub check_prereqs_libs {
       '/usr/local/include' => '/usr/local/lib',
       '/usr/include'       => '/usr/lib',
       '/usr/X11R6/include' => '/usr/X11R6/lib',
+      '/usr/pkg/include'   => '/usr/pkg/lib',
     };
 
     if( -e '/usr/lib64'  && $Config{'myarchname'} =~ /64/) {
@@ -706,8 +750,10 @@ sub check_prereqs_tools {
 
   foreach my $tool (@tools) {
     
-    if(-x File::Which::which($tool)
-    || ('pkg-config' eq $tool && defined $ENV{PKG_CONFIG} && $ENV{PKG_CONFIG} && -x File::Which::which($ENV{PKG_CONFIG}))) {
+    if((File::Which::which($tool) && -x File::Which::which($tool))
+    || ('pkg-config' eq $tool && defined $ENV{PKG_CONFIG} && $ENV{PKG_CONFIG}
+                              && File::Which::which($ENV{PKG_CONFIG})
+                              && -x File::Which::which($ENV{PKG_CONFIG}))) {
       $ret &= 1;
     }
     else {
