@@ -16,11 +16,11 @@ Alien::SDL - building, finding and using SDL binaries
 
 =head1 VERSION
 
-Version 1.422_1
+Version 1.428_1
 
 =cut
 
-our $VERSION = '1.422_1';
+our $VERSION = '1.428_1';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -33,9 +33,13 @@ Alien::SDL tries (in given order) during its installation:
 script to locate SDL libs.
 
  perl ./Build.pl --with-sdl-config=/opt/sdl/bin/sdl-config
+ 
+or using default script name 'sdl-config' by running:
 
- B<IMPORTANT NOTE:> Using --with-sdl-config avoids considering any other
- build methods; no prompt with other available build options.
+ perl ./Build.pl --with-sdl-config
+
+B<IMPORTANT NOTE:> Using --with-sdl-config avoids considering any other
+build methods; no prompt with other available build options.
 
 =item * Locate an already installed SDL via 'sdl-config' script.
 
@@ -215,7 +219,7 @@ sub get_header_version {
   $v_maj =~ s/^#define[ \t]+[A-Z_]+[ \t]+([0-9]+)[.\r\n]*$/$1/;
   my ($v_min) = grep(/^#define[ \t]+[A-Z_]+MINOR[A-Z_]*[ \t]+[0-9]+/, @raw);
   $v_min =~ s/^#define[ \t]+[A-Z_]+[ \t]+([0-9]+)[.\r\n]*$/$1/;
-  my ($v_pat) = grep(/^#define[ \t]+[A-Z_]+(PATCHLEVEL|MICRO)[A-Z_]*[ \t]+[0-9]+/, @raw);
+  my ($v_pat) = grep(/^#define[ \t]+[A-Z_]+(PATCHLEVEL|MICRO|RELEASE)[A-Z_]*[ \t]+[0-9]+/, @raw);
   $v_pat =~ s/^#define[ \t]+[A-Z_]+[ \t]+([0-9]+)[.\r\n]*$/$1/;
   return if (($v_maj eq '')||($v_min eq '')||($v_pat eq ''));
   return "$v_maj.$v_min.$v_pat";
